<?php

namespace Drupal\graphql_address\Plugin\GraphQL\Fields\Address;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * The list of administrative areas for a country.
 *
 * @GraphQLField(
 *   secure = true,
 *   id = "address_admin_areas",
 *   name = "administrativeAreas",
 *   parents = {"AddressCountry"},
 *   type = "[AddressAdministrativeArea]",
 *   arguments = {
 *     "adminAreaCodes" = "[String]",
 *   },
 * )
 */
class AddressAdministrativeAreas extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {

    $administrative_areas = [];

    // If admin areas are specified we obtain config for that given countries.
    if ($args['adminAreaCodes']) {
      foreach ($args['adminAreaCodes'] as $code) {
        /**
         * @var $administrative_area \CommerceGuys\Addressing\Subdivision\Subdivision
         */
        $administrative_area = \Drupal::service('address.subdivision_repository')->get($code, [$value['country']]);
        if($administrative_area){
          $administrative_areas[$administrative_area->getCode()] = $administrative_area;
        }
      }
    }
    // Otherwise we get them all.
    else {
      $administrative_areas = \Drupal::service('address.subdivision_repository')->getAll([$value['country']]);
    }

    /**
     * @var \CommerceGuys\Addressing\Subdivision\Subdivision $administrative_area
     */
    foreach ($administrative_areas as $admin_area_code => $administrative_area) {
      // Return an AddressAdministrativeArea object with the admin area and all
      // its parents.
      yield [
        'result_type' => 'AddressAdministrativeArea',
        'value' => $administrative_area,
        'parents' => [
          $value['country'],
          $admin_area_code,
        ],
      ];
    }
  }

}
