<?php

namespace Drupal\graphql_address\Plugin\GraphQL\Fields\Address;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * The localities dependant on a administrative area.
 *
 * @GraphQLField(
 *   secure = true,
 *   id = "address_localities",
 *   name = "localities",
 *   parents = {"AddressAdministrativeArea"},
 *   type = "[AddressLocality]",
 *   arguments = {
 *     "localityCodes" = "[String]",
 *   },
 * )
 */
class AddressLocalities extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {

    $localities = [];

    // If localities are specified we obtain config for that given countries.
    if ($args['localityCodes']) {
      foreach ($args['localityCodes'] as $code) {
        /**
         * @var $locality \CommerceGuys\Addressing\Subdivision\Subdivision
         */
        $locality = \Drupal::service('address.subdivision_repository')->get($code, $value['parents']);
        if($locality){
          $localities[$locality->getCode()] = $locality;
        }
      }
    }
    // Otherwise we get them all.
    else {
      $localities = \Drupal::service('address.subdivision_repository')->getAll($value['parents']);
    }

    $parents = $value['parents'];

    /**
     * @var \CommerceGuys\Addressing\Subdivision\Subdivision $administrative_area
     */
    foreach ($localities as $locality_code => $locality) {
      // Add the locality to the parents array.
      $locality_parents = $parents;
      $locality_parents[] = $locality_code;
      // Return a new AddressLocality GraphQL type with the locality name and
      // parents.
      yield [
        'result_type' => 'AddressLocality',
        'value' => $locality,
        'parents' => $locality_parents,
      ];
    }
  }

}
